# circular build dependency on requests-download and testpath
%bcond_without tests

%global pypi_name flit

Name:           python-%{pypi_name}
Version:        3.9.0
Release:        %mkrel 3
Summary:        Simplified packaging of Python modules
Group:          Development/Python
# ./flit/log.py: Apache-2.0
# ./flit/upload.py: PSF-2.0
License:        BSD-3-Clause AND Apache-2.0 AND PSF-2.0

URL:            https://flit.pypa.io/
Source0:        https://github.com/pypa/flit/archive/%{version}/flit-%{version}.tar.gz

# For the tests
Source1:        https://pypi.org/pypi?%3Aaction=list_classifiers#/classifiers.lst
Patch1:         flit-reqs.patch
BuildArch:      noarch
BuildRequires:  python3-devel

%if %{with tests}
BuildRequires:  python3
BuildRequires:  python3-pytest
BuildRequires:  python3-responses
BuildRequires:  python3-testpath
BuildRequires:  python3-requests-download
BuildRequires:  git-core
%endif

%global _description %{expand:
Flit is a simple way to put Python packages and modules on PyPI.
It tries to require less thought about packaging and help you avoid common
mistakes.

Flit packages a single importable module or package at a time, using the import
name as the name on PyPI. All sub-packages and data files within a package are
included automatically.}

%description %_description


%package -n python3-%{pypi_name}
Summary:        %{summary}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}

# https://pypi.python.org/pypi/tornado
# ./flit/log.py unknown version
Provides:       bundled(python3dist(tornado))

# soft dependency: (WARNING) Cannot analyze code. Pygments package not found.
Recommends:     python3-pygments

%description -n python3-%{pypi_name} %_description

%prep
%autosetup -p1 -n %{pypi_name}-%{version}


%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files flit


%check
%pyproject_check_import

%if %{with tests}
# flit attempts to download list of classifiers from PyPI, but not if it's cached
# test_invalid_classifier fails without the list
mkdir -p fake_cache/flit
cp %{SOURCE1} fake_cache/flit
export XDG_CACHE_HOME=$PWD/fake_cache

# This also runs tests of flit_core but deselecting them breaks the flit tests,
# so we run them anyway:
%pytest
%endif


%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%{_bindir}/flit


%changelog
* Thu Dec 28 2023 papoteur <papoteur> 3.9.0-3.mga10
+ Revision: 2023018
- rebuild again for python 3.12

* Fri Dec 08 2023 wally <wally> 3.9.0-2.mga10
+ Revision: 2015617
- rebuild for py3.12

* Sun Nov 26 2023 wally <wally> 3.9.0-1.mga10
+ Revision: 2009794
- new version 3.9.0
- split out flit-core into own pkg
- sync with Fedora

* Wed Nov 30 2022 papoteur <papoteur> 3.8.0-2.mga9
+ Revision: 1913549
- new 3.8.0
+ wally <wally>
- sync with Fedora where appropriate

* Mon Apr 04 2022 guillomovitch <guillomovitch> 3.7.1-1.mga9
+ Revision: 1843881
- new version 3.7.1

* Tue Mar 29 2022 umeabot <umeabot> 3.6.0-3.mga9
+ Revision: 1832173
- Mageia 9 Mass Rebuild

* Sun Feb 20 2022 mrambo3501 <mrambo3501> 3.6.0-2.mga9
+ Revision: 1781636
- rebuild for python-3.10

* Sun Feb 06 2022 wally <wally> 3.6.0-1.mga9
+ Revision: 1771922
- new version 3.6.0
- rebuild for python3.10

* Sat Aug 28 2021 wally <wally> 3.3.0-1.mga9
+ Revision: 1743272
- new version 3.3.0

* Mon Mar 15 2021 wally <wally> 3.1.0-1.mga9
+ Revision: 1703500
- new version 3.1.0
- rebuild for python 3.9

* Sat Nov 14 2020 guillomovitch <guillomovitch> 3.0.0-1.mga8
+ Revision: 1646151
- new version 3.0.0

* Tue Jun 09 2020 daviddavid <daviddavid> 2.3.0-1.mga8
+ Revision: 1591159
- new version: 2.3.0

* Thu Feb 20 2020 umeabot <umeabot> 2.2.0-2.mga8
+ Revision: 1546111
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 2.2.0-1.mga8
+ Revision: 1485939
- new version: 2.2.0

* Sat Dec 14 2019 daviddavid <daviddavid> 2.1.0-2.mga8
+ Revision: 1467109
- properly package flit-core and restore /usr/bin/flit (#1783610)

* Thu Dec 12 2019 daviddavid <daviddavid> 2.1.0-1.mga8
+ Revision: 1466064
- new version: 2.1.0

* Fri Sep 06 2019 wally <wally> 1.3-2.mga8
+ Revision: 1437998
- rebuild for python3.8

* Fri Apr 19 2019 wally <wally> 1.3-1.mga7
+ Revision: 1393412
- new version 1.3

* Tue Jan 08 2019 tv <tv> 0.11.4-3.mga7
+ Revision: 1352058
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.11.4-2.mga7
+ Revision: 1288906
- Mageia 7 Mass Rebuild

* Tue Aug 15 2017 philippem <philippem> 0.11.4-1.mga7
+ Revision: 1140806
- add group
- imported package python-flit

